@@ -5,6 +5,7 @@ from urllib.parse import urljoin
 from base64 import urlsafe_b64decode
 import requests
 from flask import Request, abort
+from . import assets
 
 GCP_PROJECT = os.environ["GCP_PROJECT"]
 FUNCTION_REGION = os.environ["FUNCTION_REGION"]
@@ -62,18 +63,21 @@ def user_info(request):
     return None
 
 
-def authorize(permission, asset):
+def authorize(permission):
     def wrap(func):
         def wrapped_func(request: Request):
             uid = user_info(request)["user_id"]
+            asset_type = permission.split(".")[0]
             granted = call(
                 "check_access",
                 uid=uid,
-                asset=asset(**request.json),
-                permission=permission
+                asset=getattr(assets, asset_type)(**request.json),
+                permission=permission,
             )["granted"]
             if not granted:
                 abort(403)
-            func(request)
+            return func(request)
+
         return wrapped_func
+
     return wrap
